California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 90 - GOVERNMENT ACQUISITION, REGULATION OF PRIVATE PROPERTY. INITIATIVE CONSTITUTIONAL AMENDMENT. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1287066 | NO ON 90, CONSERVATIONISTS FOR TAXPAYER PROTECTION, A SPONSORED COMMITTEE OF THE CALIFORNIA LEAGUE OF CONSERVATION VOTERS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1283731 | PROTECT OUR HOMES COALITION, IN SUPPORT OF PROTECTION OF PRIVATE PROPERTY FROM GOVERNMENT ACQUISITION, SPONSORED BY THE FUND FOR DEMOCRACY, WITH SUPPORT OF ADVOCATES FOR PRIVATE PROPERTY RIGHTS. | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1285334 | NO ON 90, CALIFORNIANS AGAINST THE TAXPAYERS TRAP, A COMMITTEE OF TAXPAYERS, EDUCATORS, BUSINESS, ENVIRONMENTALISTS, LOCAL GOVERNMENT AND PUBLIC SAFETY | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1291171 | CENTRAL CALIFORNIA FOR YES ON PROPOSITION 90 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1288982 | CITIZENS FOR RESPONSIBLE ELECTIONS | OPPOSE